pub struct CircularBuffer<T> {
buffer: Mutex<VecDeque<T>>,
capacity: usize,
}Expand description
A thread-safe circular buffer with FIFO eviction.
When the buffer reaches its capacity, the oldest items are automatically removed to make room for new ones.
Fields
buffer: Mutex<VecDeque<T>>capacity: usizeImplementations
Sourceimpl<T> CircularBuffer<T>
impl<T> CircularBuffer<T>